#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 some
version:              1.0.6
visibility:           public
id:                   some-1.0.6-JnCby5DWHWeK7W4U6FoTbN
key:                  some-1.0.6-JnCby5DWHWeK7W4U6FoTbN
license:              BSD-3-Clause
maintainer:           Oleg Grenrus <oleg.grenrus@iki.fi>
author:
    James Cook <mokus@deepbondi.net>, Oleg Grenrus <oleg.grenrus@iki.fi>

homepage:             https://github.com/haskellari/some
synopsis:             Existential type: Some
description:
    This library defines an existential type '\''Some'\''.

    @
    data Some f where
    \    Some :: f a -> Some f
    @

    in few variants, and utilities to work with it.

    If you are unsure which variant to use, use the one in "Data.Some" module.

category:             Data, Dependent Types
abi:                  c3ce81e46bf5c85cb1cdfe2aca88ccf6
exposed:              True
exposed-modules:
    Data.EqP Data.GADT.Compare Data.GADT.DeepSeq Data.GADT.Show
    Data.OrdP Data.Some Data.Some.Church Data.Some.GADT
    Data.Some.Newtype

hidden-modules:       Data.GADT.Internal
import-dirs:          /usr/lib/ghc-9.6.6/site-local/some-1.0.6
library-dirs:         /usr/lib/ghc-9.6.6/site-local/some-1.0.6
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/some-1.0.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-some
hs-libraries:         HSsome-1.0.6-JnCby5DWHWeK7W4U6FoTbN
depends:
    base-4.18.2.1 base-orphans-0.9.4-HkgLyhBTSRLIMV2kf9UcQx
    deepseq-1.4.8.1

haddock-interfaces:   /usr/share/doc/haskell-some/html/some.haddock
haddock-html:         /usr/share/doc/haskell-some/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

